import { CancelableEvent } from "@skeldjs/events";
import { CheckNameMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a player requests to have their name set. Only emitted if the
 * client is the host.
 */
export declare class PlayerCheckNameEvent<RoomType extends Hostable = Hostable> extends CancelableEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: CheckNameMessage | undefined;
    /**
     * The original name that the player asked for.
     */
    readonly originalName: string;
    /**
     * The altered name, i.e. the original name was taken.
     */
    alteredName: string;
    static eventName: "player.checkname";
    eventName: "player.checkname";
    constructor(room: RoomType, player: PlayerData<RoomType>, message: CheckNameMessage | undefined, 
    /**
     * The original name that the player asked for.
     */
    originalName: string, 
    /**
     * The altered name, i.e. the original name was taken.
     */
    alteredName: string);
    /**
     * Change the altered name for the player to have set.
     * @param name The name to set.
     */
    setName(name: string): void;
}
