import { CancelableEvent } from "@skeldjs/events";
import { ReportDeadBodyMessage } from "@skeldjs/protocol";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player reports a dead body of a player, telling the host to
 * begin a meeting.
 *
 * This event is only emitted if the client is the host, see
 * {@link PlayerStartMeetingEvent} to listen for a meeting being started regardless
 * of whether the client is the host or not.
 */
export declare class PlayerReportDeadBodyEvent<RoomType extends Hostable = Hostable> extends CancelableEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: ReportDeadBodyMessage | undefined;
    /**
     * The body that the player reported, or "emergency" if the player called
     * an emergency meeting.
     */
    readonly body: PlayerData<RoomType> | "emergency";
    static eventName: "player.reportbody";
    eventName: "player.reportbody";
    private _alteredBody;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: ReportDeadBodyMessage | undefined, 
    /**
     * The body that the player reported, or "emergency" if the player called
     * an emergency meeting.
     */
    body: PlayerData<RoomType> | "emergency");
    /**
     * The altered body that will be reported instead, if changed.
     */
    get alteredBody(): "emergency" | PlayerData<RoomType>;
    /**
     * Set the report to be calling an emergency meeting.
     */
    setEmergency(): void;
    /**
     * Change the body that will be reported.
     * @param body The body for the player to report.
     */
    setBody(body: PlayerData<RoomType> | "emergency"): void;
}
