"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSetSkinEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player has their player skin updated.
 */
class PlayerSetSkinEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The skin that the player had before.
     */
    oldSkin, 
    /**
     * The new skin that the player has.
     */
    newSkin) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.oldSkin = oldSkin;
        this.newSkin = newSkin;
        this.eventName = "player.setskin";
        this._alteredSkin = newSkin;
    }
    /**
     * The altered skin that the player will have set instead, if changed.
     */
    get alteredSkin() {
        return this._alteredSkin;
    }
    /**
     * Revert the player's skin back to their old skin.
     */
    revert() {
        this.setSkin(this.oldSkin);
    }
    /**
     * Change the skin that the player had set.
     * @param skin The skin to set.
     */
    setSkin(skin) {
        this._alteredSkin = skin;
    }
}
exports.PlayerSetSkinEvent = PlayerSetSkinEvent;
PlayerSetSkinEvent.eventName = "player.setskin";
//# sourceMappingURL=SetSkin.js.map