import { BasicEvent } from "@skeldjs/events";
import { SetStartCounterMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a player (i.e. the host of the room) sets the starting counter
 * located above the game code while in the lobby.
 */
export declare class PlayerSetStartCounterEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SetStartCounterMessage | undefined;
    /**
     * The old value of the counter.
     */
    readonly oldCounter: number;
    /**
     * The new value of the counter.
     */
    readonly newCounter: number;
    static eventName: "player.setstartcounter";
    eventName: "player.setstartcounter";
    private _alteredCounter;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SetStartCounterMessage | undefined, 
    /**
     * The old value of the counter.
     */
    oldCounter: number, 
    /**
     * The new value of the counter.
     */
    newCounter: number);
    /**
     * The altered value of the counter that will be set instead, if changed,
     */
    get alteredCounter(): number;
    /**
     * Revert the counter to its old value.
     */
    revert(): void;
    /**
     * Change the value of the counter that was set.
     * @param counter The value of the counter to set.
     */
    setCounter(counter: number): void;
}
