import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { ExtractEventTypes } from "@skeldjs/events";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { PlayerData } from "../PlayerData";
import { Door, DoorEvents } from "../misc/Door";
import { SystemStatusEvents } from "./events";
import { Hostable } from "../Hostable";
export interface DoorsSystemData {
    cooldowns: Map<number, number>;
    doors: boolean[];
}
export declare type DoorsSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents & DoorEvents<RoomType> & ExtractEventTypes<[]>;
/**
 * Represents a system for doors that must be manually opened.
 *
 * See {@link DoorsSystemEvents} for events to listen to.
 */
export declare class DoorsSystem<RoomType extends Hostable = Hostable> extends SystemStatus<DoorsSystemData, DoorsSystemEvents, RoomType> {
    /**
     * The cooldowns of every door.
     */
    cooldowns: Map<number, number>;
    /**
     * The doors in the map.
     */
    doors: Door<RoomType>[];
    private lastUpdate;
    constructor(ship: InnerShipStatus<RoomType>, systemType: SystemType, data?: HazelReader | DoorsSystemData);
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    private _openDoor;
    /**
     * Open a door by its ID.
     * @param doorId The ID of the door to opne.
     */
    openDoor(doorId: number): Promise<void>;
    private _closeDoor;
    /**
     * Close a door by its ID.
     * @param doorId The ID of the door to close.
     */
    closeDoor(doorId: number): Promise<void>;
    HandleRepair(player: PlayerData | undefined, amount: number, rpc: RepairSystemMessage | undefined): Promise<void>;
    Detoriorate(delta: number): void;
}
